@@ -32,7 +32,7 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(nam, SIGNAL(finished(QNetworkReply*)), this, SLOT(onRequestFinished(QNetworkReply*)));
 
     connect(&mediaPlayer, SIGNAL(metaDataChanged()), SLOT(getMetaData()));
-
+    connectBluetoothControl();
     new TextEditAutoResizer(ui->cronologyTextEdit);
 
     qDebug()<<time.elapsed();
@@ -342,7 +342,7 @@ void MainWindow::populateList(QStringList list)
     for (int i=0; i<list.size(); i++)
     {
         QListWidgetItem *item = new QListWidgetItem(ui->stationsList);
-        item->setText(list.at(i).split("--").at(0)+"\n"+list.at(i).split("--").at(1));
+        item->setText(list.at(i).split("--").at(0));//+"\n"+list.at(i).split("--").at(1));
         item->setToolTip(list.at(i).split("--").at(1));
 
         //item->setTextAlignment(Qt::AlignCenter);
@@ -560,3 +560,26 @@ void MainWindow::on_actionDoNotFilter_triggered()
     ui->stationsList->clear();
     populateList(stationsList);
 }
+
+void MainWindow::connectBluetoothControl()
+{
+    connect(&bluetoothAdapter, SIGNAL(prevButtonPressed()), this, SLOT(on_previousButton_clicked()));
+    connect(&bluetoothAdapter, SIGNAL(nextButtonPressed()), this, SLOT(on_nextButton_clicked()));
+    connect(&bluetoothAdapter, SIGNAL(toggleButtonPressed()), this, SLOT(toggleButtonPressed()));
+
+
+}
+
+void MainWindow::toggleButtonPressed()
+{
+    if ( mediaPlayer.state() == QMediaPlayer::PlayingState )
+    {
+        on_stopButton_clicked();
+    }
+
+    else if ( mediaPlayer.state() == QMediaPlayer::StoppedState )
+    {
+        on_playButton_clicked();
+    }
+
+}
