@@ -2,6 +2,7 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
+#include "bluetoothheadsetadapter.h"
 #include "stationsdb.h"
 #include "filterlistbydialog.h"
 
@@ -41,7 +42,6 @@ private slots:
     void imageLoaded(int requestId, bool);
     void onRequestFinished(QNetworkReply *reply);
     void filterList(int type, QString filter);
-
     void on_playingNowButton_clicked();
     void on_lyricsButton_clicked();
     void on_stationsButton_clicked();
@@ -61,12 +61,10 @@ private slots:
     void on_actionRestoreDefaultList_triggered();
     void on_artistLineEdit_returnPressed();
     void on_titleLineEdit_returnPressed();
-
     void on_actionFilterListByGenre_triggered();
-
     void on_actionFilterListByCountry_triggered();
-
     void on_actionDoNotFilter_triggered();
+    void toggleButtonPressed();
 
 private:
     Ui::MainWindow *ui;
@@ -76,6 +74,7 @@ private:
     QStringList stationsList;
 
     StationsDB stationsDb;
+    BluetoothHeadsetAdapter bluetoothAdapter;
 
     QNetworkAccessManager *nam;
     int imageRequest;
@@ -91,6 +90,8 @@ private:
     QStringList getDefaultList();
     void loadStationsList();
     void saveStationsList();
+    void connectBluetoothControl();
+
 
 };
 
